==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/link/lang/gl.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'gl', {
	acccessKey: 'Chave de acceso',
	advanced: 'Avanzado',
	advisoryContentType: 'Tipo de contido informativo',
	advisoryTitle: 'Título',
	anchor: {
		toolbar: 'Ancoraxe',
		menu: 'Editar a ancoraxe',
		title: 'Propiedades da ancoraxe',
		name: 'Nome da ancoraxe',
		errorName: 'Escriba o nome da ancoraxe',
		remove: 'Retirar a ancoraxe'
	},
	anchorId: 'Polo ID do elemento',
	anchorName: 'Polo nome da ancoraxe',
	charset: 'Codificación do recurso ligado',
	cssClasses: 'Clases da folla de estilos',
	emailAddress: 'Enderezo de correo',
	emailBody: 'Corpo da mensaxe',
	emailSubject: 'Asunto da mensaxe',
	id: 'ID',
	info: 'Información da ligazón',
	langCode: 'Código do idioma',
	langDir: 'Dirección de escritura do idioma',
	langDirLTR: 'Esquerda a dereita (LTR)',
	langDirRTL: 'Dereita a esquerda (RTL)',
	menu: 'Editar a ligazón',
	name: 'Nome',
	noAnchors: '(Non hai ancoraxes dispoñíbeis no documento)',
	noEmail: 'Escriba o enderezo de correo',
	noUrl: 'Escriba a ligazón URL',
	other: '<outro>',
	popupDependent: 'Dependente (Netscape)',
	popupFeatures: 'Características da xanela emerxente',
	popupFullScreen: 'Pantalla completa (IE)',
	popupLeft: 'Posición esquerda',
	popupLocationBar: 'Barra de localización',
	popupMenuBar: 'Barra do menú',
	popupResizable: 'Redimensionábel',
	popupScrollBars: 'Barras de desprazamento',
	popupStatusBar: 'Barra de estado',
	popupToolbar: 'Barra de ferramentas',
	popupTop: 'Posición superior',
	rel: 'Relación',
	selectAnchor: 'Seleccionar unha ancoraxe',
	styles: 'Estilo',
	tabIndex: 'Índice de tabulación',
	target: 'Destino',
	targetFrame: '<marco>',
	targetFrameName: 'Nome do marco de destino',
	targetPopup: '<xanela emerxente>',
	targetPopupName: 'Nome da xanela emerxente',
	title: 'Ligazón',
	toAnchor: 'Ligar coa ancoraxe no testo',
	toEmail: 'Correo',
	toUrl: 'URL',
	toolbar: 'Ligazón',
	type: 'Tipo de ligazón',
	unlink: 'Eliminar a ligazón',
	upload: 'Enviar'
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/link/lang/gl.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'gl', {
	acccessKey: 'Chave de acceso',
	advanced: 'Avanzado',
	advisoryContentType: 'Tipo de contido informativo',
	advisoryTitle: 'Título',
	anchor: {
		toolbar: 'Ancoraxe',
		menu: 'Editar a ancoraxe',
		title: 'Propiedades da ancoraxe',
		name: 'Nome da ancoraxe',
		errorName: 'Escriba o nome da ancoraxe',
		remove: 'Retirar a ancoraxe'
	},
	anchorId: 'Polo ID do elemento',
	anchorName: 'Polo nome da ancoraxe',
	charset: 'Codificación do recurso ligado',
	cssClasses: 'Clases da folla de estilos',
	download: 'Forzar a descarga',
	displayText: 'Amosar o texto',
	emailAddress: 'Enderezo de correo',
	emailBody: 'Corpo da mensaxe',
	emailSubject: 'Asunto da mensaxe',
	id: 'ID',
	info: 'Información da ligazón',
	langCode: 'Código do idioma',
	langDir: 'Dirección de escritura do idioma',
	langDirLTR: 'Esquerda a dereita (LTR)',
	langDirRTL: 'Dereita a esquerda (RTL)',
	menu: 'Editar a ligazón',
	name: 'Nome',
	noAnchors: '(Non hai ancoraxes dispoñíbeis no documento)',
	noEmail: 'Escriba o enderezo de correo',
	noUrl: 'Escriba a ligazón URL',
	noTel: 'Please type the phone number', // MISSING
	other: '<outro>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dependente (Netscape)',
	popupFeatures: 'Características da xanela emerxente',
	popupFullScreen: 'Pantalla completa (IE)',
	popupLeft: 'Posición esquerda',
	popupLocationBar: 'Barra de localización',
	popupMenuBar: 'Barra do menú',
	popupResizable: 'Redimensionábel',
	popupScrollBars: 'Barras de desprazamento',
	popupStatusBar: 'Barra de estado',
	popupToolbar: 'Barra de ferramentas',
	popupTop: 'Posición superior',
	rel: 'Relación',
	selectAnchor: 'Seleccionar unha ancoraxe',
	styles: 'Estilo',
	tabIndex: 'Índice de tabulación',
	target: 'Destino',
	targetFrame: '<marco>',
	targetFrameName: 'Nome do marco de destino',
	targetPopup: '<xanela emerxente>',
	targetPopupName: 'Nome da xanela emerxente',
	title: 'Ligazón',
	toAnchor: 'Ligar coa ancoraxe no testo',
	toEmail: 'Correo',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Ligazón',
	type: 'Tipo de ligazón',
	unlink: 'Eliminar a ligazón',
	upload: 'Enviar'
} );
